@@ -2,7 +2,9 @@
 function (name) 
 {
     if (!exists("genotypesNames")) {
-        genotypesNames <- NULL; rm(genotypesNames); data(genotypesNames, package = "noia")
+        genotypesNames <- NULL
+        rm(genotypesNames)
+        data(genotypesNames, package = "noia")
     }
     ans <- NULL
     for (n in name) {
